# Generated by Django 3.2.25 on 2024-05-22 09:25

import aldryn_apphooks_config.fields
from django.contrib.contenttypes.models import ContentType
from django.db import migrations, models
import django.db.models.deletion
import taggit_autosuggest.managers


def migrate_plugins(apps, schema_editor):
    UpcomingEventsPlugin = apps.get_model("djangocms_blog_agenda.UpcomingEventsPlugin")
    UpcomingEventsPluginNew = apps.get_model(
        "djangocms_blog_agenda.UpcomingEventsPluginNew"
    )
    TaggedItem = apps.get_model("taggit.TaggedItem")
    ct_plugin_new = ContentType.objects.get_for_model(UpcomingEventsPluginNew)
    ct_plugin = ContentType.objects.get_for_model(UpcomingEventsPlugin)

    for plugin in UpcomingEventsPlugin.objects.all():
        new_plugin = UpcomingEventsPluginNew(
            cmsplugin_ptr_id=plugin.cmsplugin_ptr.id,
            current_site=plugin.current_site,
            template_folder=plugin.template_folder,
            latest_posts=plugin.latest_posts,
            app_config=plugin.app_config,
        )
        new_plugin.save_base(raw=True)
        tags = TaggedItem.objects.filter(
            content_type_id=ct_plugin.id, object_id=plugin.id
        )
        for tag in tags:
            TaggedItem.objects.create(
                content_type_id=ct_plugin_new.id, object_id=new_plugin.pk, tag=tag.tag
            )
        for category in plugin.categories.all():
            new_plugin.categories.add(category)


class Migration(migrations.Migration):
    dependencies = [
        ("cms", "0022_auto_20180620_1551"),
        ("djangocms_blog", "0042_alter_authorentriesplugin_cmsplugin_ptr_and_more"),
        ("taggit", "0005_auto_20220424_2025"),
        ("djangocms_blog_agenda", "0004_pasteventsplugin"),
    ]

    operations = [
        migrations.CreateModel(
            name="UpcomingEventsPluginNew",
            fields=[
                (
                    "cmsplugin_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        related_name="djangocms_blog_agenda_upcomingeventspluginnew",
                        serialize=False,
                        to="cms.cmsplugin",
                    ),
                ),
                (
                    "current_site",
                    models.BooleanField(
                        default=True,
                        help_text="Select items from the current site only",
                        verbose_name="current site",
                    ),
                ),
                (
                    "template_folder",
                    models.CharField(
                        choices=[
                            ("plugins", "Modèle par défaut"),
                            ("detail_plugins", "Modèle d’affichage dans les articles"),
                        ],
                        default="plugins",
                        help_text="Select plugin template to load for this instance",
                        max_length=200,
                        verbose_name="Plugin template",
                    ),
                ),
                (
                    "latest_posts",
                    models.IntegerField(
                        default=5,
                        help_text="The number of latests articles to be displayed.",
                        verbose_name="articles",
                    ),
                ),
                (
                    "show_until_event_end",
                    models.BooleanField(
                        default=True, verbose_name="Show events until their end date"
                    ),
                ),
                (
                    "app_config",
                    aldryn_apphooks_config.fields.AppHookConfigField(
                        blank=True,
                        help_text="When selecting a value, the form is reloaded to get the updated default",
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        to="djangocms_blog.blogconfig",
                        verbose_name="app. config",
                    ),
                ),
                (
                    "categories",
                    models.ManyToManyField(
                        blank=True,
                        help_text="Show only the blog articles tagged with chosen categories.",
                        to="djangocms_blog.BlogCategory",
                        verbose_name="filter by category",
                    ),
                ),
                (
                    "tags",
                    taggit_autosuggest.managers.TaggableManager(
                        blank=True,
                        help_text="Show only the blog articles tagged with chosen tags.",
                        related_name="djangocms_blog_agenda_upcoming_events",
                        through="taggit.TaggedItem",
                        to="taggit.Tag",
                        verbose_name="filter by tag",
                    ),
                ),
            ],
            options={
                "verbose_name": "Upcoming events plugin",
                "verbose_name_plural": "Upcoming events plugins",
            },
            bases=("cms.cmsplugin",),
        ),
        migrations.RunPython(migrate_plugins, migrations.RunPython.noop),
    ]
